@@ -249,8 +249,11 @@ class AccountDialog(QtCore.QObject, qwrappers.WindowWrapper):
 		self._cancelButton = QtGui.QPushButton("&Cancel")
 		self._cancelButton.clicked.connect(self._on_settings_cancel)
 		self._buttonLayout = QtGui.QHBoxLayout()
+		self._buttonLayout.addStretch()
 		self._buttonLayout.addWidget(self._cancelButton)
+		self._buttonLayout.addStretch()
 		self._buttonLayout.addWidget(self._applyButton)
+		self._buttonLayout.addStretch()
 
 		self._layout.addWidget(self._scrollSettings)
 		self._layout.addLayout(self._buttonLayout)
@@ -357,11 +360,14 @@ class AccountDialog(QtCore.QObject, qwrappers.WindowWrapper):
 		self._callbackSelector.addItem("Not Set", "")
 
 		uglyDefault = misc_utils.make_ugly(default)
+		if not uglyDefault:
+			uglyDefault = default
 		for number, description in choices.iteritems():
 			prettyNumber = misc_utils.make_pretty(number)
 			uglyNumber = misc_utils.make_ugly(number)
 			if not uglyNumber:
-				continue
+				prettyNumber = number
+				uglyNumber = number
 
 			self._callbackSelector.addItem("%s - %s" % (prettyNumber, description), uglyNumber)
 			if uglyNumber == uglyDefault:
@@ -857,7 +863,9 @@ class SMSEntryWindow(qwrappers.WindowWrapper):
 
 		self._buttonLayout = QtGui.QHBoxLayout()
 		self._buttonLayout.addWidget(self._characterCountLabel)
+		self._buttonLayout.addStretch()
 		self._buttonLayout.addWidget(self._singleNumberSelector)
+		self._buttonLayout.addStretch()
 		self._buttonLayout.addWidget(self._smsButton)
 		self._buttonLayout.addWidget(self._dialButton)
 		self._buttonLayout.addWidget(self._cancelButton)
